@@ -16,12 +16,17 @@ BIFIE.mva <- function( BIFIEobj , missvars , covariates=NULL , se=TRUE ){
 		varnames <- unique( c(missvars , covariates ) )
 		bifieobj <- BIFIE.BIFIEdata2BIFIEcdata( bifieobj , varnames )
 						}
-	
-	
+
+	if ( is.null(covariates) ){
+		covariates <- "one"
+					}
+						
 	# if covariates = NULL, then create a garbage variable
 	if ( is.null(covariates) ){ 
+#	if ( FALSE ){ 
 		N <- bifieobj$N
 		transform.formula <-  paste0( "~ 0 + I ( runif( " , N , " , 0 , 1E-10) ) " )
+#		transform.formula <-  paste0( "~ 0 + I ( 1: ", N , "  ) " )
 		bifieobj <- BIFIE.data.transform( bifieobj , transform.formula ,  "_null" )  
 		covariates <- bifieobj$varnames.added
 		se <- FALSE
@@ -36,7 +41,7 @@ BIFIE.mva <- function( BIFIEobj , missvars , covariates=NULL , se=TRUE ){
 	RR <- bifieobj$RR
 	datalistM <- bifieobj$datalistM
     fayfac <- bifieobj$fayfac													
-												
+		
 	# start with a compact BIFIEdata object
 	varnames <- unique( c(missvars , covariates ) )
 #	varnames <- setdiff( varnames , "one" )
@@ -44,7 +49,9 @@ BIFIE.mva <- function( BIFIEobj , missvars , covariates=NULL , se=TRUE ){
 	# assume that bifieobj is already in cdata format
 	
 	# define selected response indicators
-	datalistM_ind_sel <- bifieobj$datalistM_ind[ , missvars ]											
+
+	missvars_index <- match( missvars , colnames(bifieobj$dat1) )
+	datalistM_ind_sel <- bifieobj$datalistM_ind[ , missvars_index , drop=FALSE ]											
 
 	respvars <- paste0("resp_" , missvars )
 	colnames(datalistM_ind_sel) <- respvars
@@ -61,6 +68,22 @@ BIFIE.mva <- function( BIFIEobj , missvars , covariates=NULL , se=TRUE ){
 	# select dataset
 	bifieobj <- BIFIE.BIFIEcdata2BIFIEdata( bifieobj , varnames = varnames1 )
 	
+	RR <- bifieobj$RR
+    do_test <- TRUE
+    if (RR < 2 ){
+		wgtrep <- bifieobj$wgtrep 
+		do_test <- FALSE
+		wgtrep <- cbind( wgtrep , wgtrep + runif( nrow(wgtrep) , 0 , 1E-4) )
+		bifieobj$wgtrep <- wgtrep
+		bifieobj$RR <- 2
+				}
+	
+	if ( is.null( covariates) ){
+			do_test <- FALSE 
+			se <- FALSE
+			covariates <- "one"
+				}
+	
 	if (RR==1){ RR <- 0 }
 	if ( ! se ){ 
 		N11 <- length(wgt)
@@ -80,26 +103,32 @@ BIFIE.mva <- function( BIFIEobj , missvars , covariates=NULL , se=TRUE ){
 	res_list <- list( 1:VV)
 	dfr <- NULL
 	
+	RR <- bifieobj$RR
+
+	
 	for (vv in 1:VV){
 		# vv <- 1
 		rvv <- respvars[vv]
 		res.vv <- as.list(1:2)
 		names(res.vv) <- c("stat" , "dstat")	
-		
 		res <- BIFIE.univar( bifieobj , vars = covariates , group= rvv, 
 					group_values = 0:1 )
 		res.vv$stat <- res$stat
-		res1 <- BIFIE.univar.test( res )
+		
+		res1 <- BIFIE.univar.test( res , wald_test = FALSE )					
 		res.vv$dstat <- res1$stat.dstat
+						
 		res_list[[vv]] <- res.vv
 		# collect results
 		dfr.vv <- data.frame( "respvar"= rep(rvv,CVV) )		
 		dfr.vv$missprop <- res$stat$Nweight[1] / ( res$stat$Nweight[1] + res$stat$Nweight[2] )
 		dfr.vv$covariate <- covariates
-		dfr.vv$d <- res1$stat.dstat$d
-		dfr.vv$d_SE <- res1$stat.dstat$d_SE
-		dfr.vv$t <- res1$stat.dstat$t
-		dfr.vv$p <- res1$stat.dstat$p
+		if ( do_test ){
+			dfr.vv$d <- res1$stat.dstat$d
+			dfr.vv$d_SE <- res1$stat.dstat$d_SE
+			dfr.vv$t <- res1$stat.dstat$t
+			dfr.vv$p <- res1$stat.dstat$p
+						}						
 		dfr.vv$M_resp <- res$stat$M[ seq(2,2*CVV , 2 ) ]
 		dfr.vv$M_miss <- res$stat$M[ seq(1,2*CVV , 2 ) ]
 		dfr.vv$SD_resp <- res$stat$SD[ seq(2,2*CVV , 2 ) ]
@@ -107,11 +136,16 @@ BIFIE.mva <- function( BIFIEobj , missvars , covariates=NULL , se=TRUE ){
 		dfr <- rbind( dfr , dfr.vv )
 				}
 	if ( covariates[1] == "_null" ){ se <- FALSE }
-	if ( ( ! se ) &  ( RR==0 ) ){				
+	
+	if ( ! do_test ){
+		RR <- 0
+				  }
+	
+	if ( ( ! se ) |  ( RR==0 ) ){
 		dfr$t <- dfr$p <- dfr$d_SE <-  NULL
 				}						
 	
-	if ( covariates[1] == "_null" ){			
+	if ( covariates[1] %in% c("_null","one") ){			
 			dfr$covariate <- dfr$d <- dfr$M_resp  <- NULL
 			dfr$M_miss <- dfr$SD_resp <- dfr$SD_miss <- NULL						
 			}
@@ -122,6 +156,7 @@ BIFIE.mva <- function( BIFIEobj , missvars , covariates=NULL , se=TRUE ){
 	res1 <- list( "stat.mva" = dfr , "res_list" = res_list , 
 			"timediff" = timediff ,
 			"N" = N , "Nimp" = Nimp , "RR" = RR , "fayfac"=fayfac ,
+			"NMI" = BIFIEobj$NMI , "Nimp_NMI" = BIFIEobj$Nimp_NMI , 
 			"CALL"= cl
 			# "itempair_index" = itempair_index , "GG"=GG ,
 			# "parnames" = parnames
